==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/performance-tests/Latency/Thread_Pool/run_test.pl <==
eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
    & eval 'exec perl -S $0 $argv:q'
    if 0;

# run_test.pl,v 1.6 2004/11/19 16:53:55 elliott_c Exp
# -*- perl -*-

use lib "../../../../bin";
use PerlACE::Run_Test;

$status = 0;
$iorfile = PerlACE::LocalFile ("test.ior");

$iteration = 150000;

for ($iter = 0; $iter <= $#ARGV; $iter++) {
    if ($ARGV[$iter] eq "-h" || $ARGV[$iter] eq "-?") {
      print "Run_Test Perl script for Thread pool Latency test\n\n";
      print "run_test [-n num] [-h] \n";
      print "\n";
      print "-n num              -- runs the client num times\n";
      print "-h                  -- prints this information\n";
      exit 0;
  }
  elsif ($ARGV[$iter] eq "-n") {
      $iteration = $ARGV[$iter + 1];
      $i++;
  }
    
}

print STDERR "================ Thread Pool Latency Test\n";

unlink $iorfile;

$SV = new PerlACE::Process ("server",
                            "-o $iorfile");

$CL = new PerlACE::Process ("client",
                            "-k file://$iorfile "
                            . " -i $iteration");

$SV->Spawn ();

if (PerlACE::waitforfile_timed ($iorfile, 15) == -1) {
    print STDERR "ERROR: cannot find file <$iorfile>\n";
    $SV->Kill ();
    exit 1;
}

$client = $CL->SpawnWaitKill (480);
$server = $SV->WaitKill (10);

unlink $iorfile;

if ($client != 0) {
    print STDERR "ERROR: client returned $client\n";
    $status = 1;
}

if ($server != 0) {
    print STDERR "ERROR: server returned $server\n";
    $status = 1;
}

exit $status;

==> ace_5.6.3.orig.tar.gz: ACE_wrappers/TAO/performance-tests/Latency/Thread_Pool/run_test.pl <==
eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
    & eval 'exec perl -S $0 $argv:q'
    if 0;

# $Id: run_test.pl 78111 2007-04-19 12:29:25Z johnnyw $
# -*- perl -*-

use lib "$ENV{ACE_ROOT}/bin";
use PerlACE::Run_Test;

$status = 0;
$iorfile = PerlACE::LocalFile ("test.ior");

$iteration = 150000;

for ($iter = 0; $iter <= $#ARGV; $iter++) {
    if ($ARGV[$iter] eq "-h" || $ARGV[$iter] eq "-?") {
      print "Run_Test Perl script for Thread pool Latency test\n\n";
      print "run_test [-n num] [-h] \n";
      print "\n";
      print "-n num              -- runs the client num times\n";
      print "-h                  -- prints this information\n";
      exit 0;
  }
  elsif ($ARGV[$iter] eq "-n") {
      $iteration = $ARGV[$iter + 1];
      $i++;
  }
    
}

print STDERR "================ Thread Pool Latency Test\n";

unlink $iorfile;

$SV = new PerlACE::Process ("server",
                            "-o $iorfile");

$CL = new PerlACE::Process ("client",
                            "-k file://$iorfile "
                            . " -i $iteration");

$SV->Spawn ();

if (PerlACE::waitforfile_timed ($iorfile, $PerlACE::wait_interval_for_process_creation) == -1) {
    print STDERR "ERROR: cannot find file <$iorfile>\n";
    $SV->Kill ();
    exit 1;
}

$client = $CL->SpawnWaitKill (480);
$server = $SV->WaitKill (10);

unlink $iorfile;

if ($client != 0) {
    print STDERR "ERROR: client returned $client\n";
    $status = 1;
}

if ($server != 0) {
    print STDERR "ERROR: server returned $server\n";
    $status = 1;
}

exit $status;
